@@ -87,14 +87,17 @@
 (defun cfm--outer-get-namespace::class::method ()
   (let* ((namespace (cfm--get-namespace))
          (class     (cfm--get-class (if namespace 1 0)))
-         (result    nil))
+         (result    nil)
+         (method    nil))
     (if class
-        (let ((method (or (car (cfm--get-method (if namespace 2 1))) "<No Method>")))
+        (progn
+          (setq method (or (nth 0 (cfm--get-method (if namespace 2 1))) "<No Method>"))
           ;;(debug "Roger Ramjet")
           (setq result (concat (if namespace (concat namespace "::") "") class "::" method)))
       ;;(debug "Amber Dempsey")
       (setq result (concat "::" (if namespace (concat namespace "::") "")
                            (cfm--get-class::method (if namespace 1 0)))))
+    ;;(debug "Dire Straits: My Parties")
     result
     ))
 
@@ -482,7 +485,7 @@ d-speedbar has been activated.")
           (setq p2 (point))
           (goto-char p0)
           ;;                                        1                                                                          2                                                                                                                    3                             4
-          (setq str-void-main (concat "^" spaces "\\(public +\\|protected +\\|private +\\|final +\\|abstract +\\|static +\\)*\\(void +\\|boolean[][]* +\\|char[][]* +\\|int[][]* +\\|float[][]* +\\|double[][]* +\\|[A-Z][a-zA-Z0-9_<>]*[][]* +\\)\\([a-z][a-zA-Z0-9_]*\\)[ \t]*\\(([^()]*)\\)"))
+          ;;(setq str-void-main (concat "^" spaces "\\(public +\\|protected +\\|private +\\|final +\\|abstract +\\|static +\\)*\\(void +\\|boolean[][]* +\\|char[][]* +\\|int[][]* +\\|float[][]* +\\|double[][]* +\\|[A-Z][a-zA-Z0-9_<>]*[][]* +\\)\\([a-z][a-zA-Z0-9_]*\\)[ \t]*\\(([^()]*)\\)"))
           ;;(setq str (concat "^" spaces "\\(public +\\|protected +\\|private +\\|final +\\|abstract +\\|static +\\)*\\(void +\\|boolean[][]* +\\|short[][]* +\\|int[][]* +\\|long[][]* +\\|float[][]* +\\|double[][]* +\\|[A-Z][a-zA-Z0-9_<>,]*[][]* +\\)\\([a-z][a-zA-Z0-9_]*[ \t]*\\)\\(([^()]*)\\)"))
           ;;                                                                      1                   2
           (setq str (concat "^" spaces "[a-z][-a-zA-Z0-9_ .:!@#$%^&*/+<>]*[ \t]+\\([a-zA-Z0-9_:]+\\)\\(([^()]*)\\)"))
@@ -506,9 +509,10 @@ d-speedbar has been activated.")
             (end-of-line)
             (forward-line 1)
             (beginning-of-line)
-            (if (not (and 'all-ways (looking-at "[ \t]*{")))
+            (if (not (looking-at "[ \t]*{"))
                 (return (list name (concat args ";") 'whistle)))
             ;;(message "I have a bird to whistle and I have a bird to sing")
+            (setq p (point))
             (setq found t))
            ;; ------------------------------------------------------
            ((re-search-backward str nil t)
@@ -522,12 +526,14 @@ d-speedbar has been activated.")
             (forward-char -1)
             (assert (looking-at "[ \t]*{"))
             ;;(message "Some people tell me that the word blues ain't bad")
+            (setq p (point))
             (setq found t))
            ;; ------------------------------------------------------
            )
           ;;(debug "Miles Davis: Birth Of The Cool")
           ;; -------------------------------------------------------
           (when found
+            (goto-char p)
             (skip-chars-forward " \t\r\n")
             (assert (and 7 (looking-at "{")))
             (setq bra (point))
@@ -566,9 +572,9 @@ d-speedbar has been activated.")
                              (d-trim-string class-name)))
           )
         )
-        result
-        )
-    )
+      result
+      ) ;; END LET!
+    ) ;; END BLOCK!
   )
 
 (defun cfm--get-cfunction ()
